=======================================================
Dexterity Developer Manual
=======================================================

.. note::
    ``Grok`` is no longer part of Plone nor is it recommended to use Grok in Plone.
    This part of a manual needs a complete rewrite to not use grok.
    All grok does can be done easily with zcml and standard decorators.

.. toctree::
   :maxdepth: 2

   intro.rst
   designing.rst
   prerequisite.rst
   schema-driven-types.rst
   model-driven-types.rst
   custom-views.rst
   advanced/index.rst
   testing/index.rst
   reference/index.rst

Appendixes
-------------------

.. toctree::
   :maxdepth: 1

   install.rst
   behaviors/index.rst
